cmd

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: AGPL-3.0 Imports: 27 Imported by: 0

Documentation

Overview

Package cmd exposes the ibdm Cobra commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunCmd

func RunCmd() *cobra.Command

RunCmd returns the Cobra command that starts an event-stream integration.

func SyncCmd

func SyncCmd() *cobra.Command

SyncCmd returns the Cobra command that starts a sync integration.

Types

This section is empty.

Jump to