server

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Overview

Package server contains the server implementation for the IBDM application. It sets up the HTTP server using the Fiber framework, configures middleware for logging, and defines routes for health checks and service status.

Index

Constants

This section is empty.

Variables

var (
	ErrServerListen   = errors.New("server listen error")
	ErrServerShutdown = errors.New("server shutdown error")
)
var (
	ErrEnvVariablesNotValid = errors.New("environment variables not valid")
)

Functions

func LoadServerConfig

func LoadServerConfig() (*config, error)

Types

type Server

type Server interface {
	AddRoute(method string, path string, handler func(ctx context.Context, headers http.Header, body []byte) error)
	Start() error
	Stop(context.Context) error
	StartAsync() <-chan error
}

func NewServer

func NewServer(ctx context.Context) (Server, error)

Directories

Path Synopsis

Jump to