Documentation
¶
Overview ¶
Package server contains the server implementation for the IBDM application. It sets up the HTTP server using the Fiber framework, configures middleware for logging, and defines routes for health checks and service status.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrServerListen = errors.New("server listen error") ErrServerShutdown = errors.New("server shutdown error") )
var (
ErrEnvVariablesNotValid = errors.New("environment variables not valid")
)
Functions ¶
func LoadServerConfig ¶
func LoadServerConfig() (*config, error)
Types ¶
Click to show internal directories.
Click to hide internal directories.